@@ -162,13 +162,13 @@ namespace
 
 [[nodiscard]] bool isPGP(const KMime::Content *part, bool allowOctetStream = false)
 {
-    const auto ct = static_cast<KMime::Headers::ContentType *>(part->headerByType("Content-Type"));
+    const auto ct = part->contentType();
     return ct && (ct->isSubtype("pgp-encrypted") || ct->isSubtype("encrypted") || (allowOctetStream && ct->isMimeType("application/octet-stream")));
 }
 
 [[nodiscard]] bool isSMIME(const KMime::Content *part)
 {
-    const auto ct = static_cast<KMime::Headers::ContentType *>(part->headerByType("Content-Type"));
+    const auto ct = part->contentType();
     return ct && (ct->isSubtype("pkcs7-mime") || ct->isSubtype("x-pkcs7-mime"));
 }
 
@@ -250,7 +250,7 @@ KMime::Message::Ptr CryptoUtils::decryptMessage(const KMime::Message::Ptr &msg,
         } else if (isSMIME(msg.data())) {
             protoName = GpgME::CMS;
         } else {
-            const auto blocks = prepareMessageForDecryption(msg->decodedContent());
+            const auto blocks = prepareMessageForDecryption(msg->decodedBody());
             QByteArray content;
             for (const auto &block : blocks) {
                 if (block.type() == PgpMessageBlock) {
@@ -294,7 +294,7 @@ KMime::Message::Ptr CryptoUtils::decryptMessage(const KMime::Message::Ptr &msg,
 
     wasEncrypted = true;
     QByteArray outData;
-    auto inData = multipart ? msg->encodedContent() : msg->decodedContent(); // decodedContent in fact returns decoded body
+    auto inData = multipart ? msg->encodedContent() : msg->decodedBody(); // decodedContent in fact returns decoded body
     auto decrypt = proto->decryptJob();
     auto result = decrypt->exec(inData, outData);
     if (result.error()) {
